summaryrefslogtreecommitdiffstats
path: root/win/CS/HandBrakeWPF/ViewModels/PictureSettingsViewModel.cs
diff options
context:
space:
mode:
Diffstat (limited to 'win/CS/HandBrakeWPF/ViewModels/PictureSettingsViewModel.cs')
-rw-r--r--win/CS/HandBrakeWPF/ViewModels/PictureSettingsViewModel.cs17
1 files changed, 8 insertions, 9 deletions
diff --git a/win/CS/HandBrakeWPF/ViewModels/PictureSettingsViewModel.cs b/win/CS/HandBrakeWPF/ViewModels/PictureSettingsViewModel.cs
index f7ca69f6c..4a1a76cd6 100644
--- a/win/CS/HandBrakeWPF/ViewModels/PictureSettingsViewModel.cs
+++ b/win/CS/HandBrakeWPF/ViewModels/PictureSettingsViewModel.cs
@@ -393,21 +393,20 @@ namespace HandBrakeWPF.ViewModels
#region Public Methods
/// <summary>
/// Setup the window after a scan.
/// </summary>
- /// <param name="selectedTitle">
- /// The selected title.
+ /// <param name="title">
+ /// The title.
/// </param>
- /// <param name="currentTask">
- /// The current task.
+ /// <param name="preset">
+ /// The preset.
/// </param>
- /// <param name="currentPreset">
- /// The Current preset
+ /// <param name="task">
+ /// The task.
/// </param>
- public void Setup(Title selectedTitle, EncodeTask currentTask, Preset currentPreset)
+ public void SetSource(Title title, Preset preset, EncodeTask task)
{
}
-
#endregion
}
} \ No newline at end of file
@@ -393,21 +393,20 @@ namespace HandBrakeWPF.ViewModels
#region Public Methods
/// <summary>
- /// Setup the window after a scan.
+ /// Setup this window for a new source
/// </summary>